function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(68, 1);
T53 = params(2)*exp(y(90))/exp(y(51));
T90 = (1-params(6))/params(6)*exp(y(29))*1/(1-exp(y(69)));
T117 = exp(y(57))*exp(y(23))^params(20)*exp(y(1))^params(10);
T121 = exp(y(13))^(1-params(10));
T158 = exp(y(47))/exp(y(19));
T179 = params(2)*(1-params(13))*exp(y(90))/exp(y(51));
T205 = exp(.5*(params(14)-exp(y(39)))/(exp(y(39))*params(14)*params(15)));
T225 = 1/exp(y(41))*exp(y(32))/exp(y(39));
T245 = y(66)*exp(y(47))*exp(y(24))*exp(y(39))/(1-exp(y(24)));
T263 = 1-params(12)/2*y(36)^2;
T286 = exp(y(17))/exp(y(2));
T289 = exp(y(35))*(T263-params(12)*y(36)*T286);
T296 = exp(y(80))/exp(y(17));
T299 = exp(y(85))*T53*params(12)*y(86)*T296^2;
T338 = exp(y(90))/exp(y(51))*params(2)*(1-params(5))*(1-params(13))*exp(y(21));
T340 = exp(y(83))*(1-exp(y(81)))*T338;
T348 = exp(y(47))*exp(y(40))/exp(y(19));
T396 = params(20)*params(9)^2;
T406 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T396)/(1-2*params(10)+params(10)^2));
T422 = 0.7071067811865475/params(9)*(params(8)+T396+(-log(exp(y(18))))+params(10)*log(exp(y(18)))-params(10)*params(8))/((-1)+params(10));
T442 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T444 = T406*(erf(T422)-erf(0.7071067811865475*(params(8)+T396+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T442/params(11)^0.5;
T464 = exp(y(45))*(1-params(10))*exp(y(34))/exp(y(13));
T467 = exp(y(18))/exp(y(23));
T476 = exp(y(45))*params(10)*exp(y(34))/exp(y(1));
T635 = params(6)/(1-params(6));
T640 = exp(y(21))*y(66)*exp(y(90))*params(2)*(1-params(5))*(1-params(13))/exp(y(51));
T684 = (exp(y(46))+T158)*exp(y(40));
T765 = (-(exp(y(17))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T815 = (-(exp(y(47))*exp(y(19))))/(exp(y(19))*exp(y(19)));
T951 = (-(params(2)*exp(y(90))*exp(y(51))))/(exp(y(51))*exp(y(51)));
T956 = (-(exp(y(90))*exp(y(51))))/(exp(y(51))*exp(y(51)));
lhs =y(49);
rhs =log(exp(y(12)));
residual(1)= lhs-rhs;
lhs =y(50);
rhs =y(49)+params(2)*y(89);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(47)))+(1-params(5))*(1-exp(y(24)))*exp(y(7))+(1-params(5))*(1-exp(y(24)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(19))+(1-params(5))*(1-params(13))*T53*((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(66));
residual(5) = (-exp(y(53)))+exp(y(31))-params(17)/exp(y(19))-y(66);
residual(6) = (-exp(y(28)))+T90;
residual(7) = (-exp(y(31)))+exp(y(15))-params(6)*(exp(y(25))-exp(y(53)));
residual(8) = (-exp(y(45)))+T117*T121;
residual(9) = (-exp(y(38)))+exp(y(41))*exp(y(44))-exp(y(47))*exp(y(15))-params(17)*exp(y(46))-exp(y(26))*exp(y(48))-y(66)*exp(y(47))*exp(y(24))/(1-exp(y(24)));
residual(10) = (-exp(y(37)))+params(18)+y(67)+params(17)*(exp(y(46))+T158);
residual(11) = (-exp(y(44)))+exp(y(45))/exp(y(39));
residual(12) = (-exp(y(41)))+exp(y(43))*exp(y(34));
residual(13) = (-exp(y(37)))+T179*(exp(y(87))+exp(y(88)));
residual(14) = (-exp(y(39)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(41))*T205;
residual(16) = (-exp(y(43)))+exp(y(42))/(exp(y(42))-1);
residual(17) = (-exp(y(42)))+1+exp(y(39))*params(15);
residual(18) = (-exp(y(44)))+T225;
residual(19) = (-exp(y(32)))+exp(y(55))+exp(y(17))+params(17)*exp(y(14))+(params(18)+y(67))*exp(y(40))+T245+exp(y(68));
residual(20) = (-exp(y(16)))+exp(y(1))*(1-params(19))+exp(y(17))*T263;
residual(21) = (-exp(y(35)))+T53*(exp(y(84))*(1-exp(y(70)))+(1-params(19))*exp(y(85)));
residual(22) = (-1)+T289+T299;
residual(23) = T286-y(36)-1;
residual(24) = (1-params(5))*(1-params(13))*T53*((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(91))+exp(y(25))-exp(y(27))-exp(y(15));
residual(25) = (-exp(y(29)))+(1-exp(y(69)))*exp(y(15))-exp(y(30))+(1-params(5))*(1-params(13))*T53*(1-exp(y(81)))*exp(y(83));
residual(26) = (-exp(y(30)))+params(23)+y(65)+T340;
residual(27) = (-exp(y(14)))+exp(y(46))*(exp(y(39))+exp(y(40)))+T348;
residual(28) = (-exp(y(47)))+exp(y(13))/exp(y(39));
residual(29) = (-exp(y(48)))+exp(y(1))/exp(y(39));
residual(30) = (-exp(y(20)))+params(16)*exp(y(14))^(1-params(7))*exp(y(22))^params(7);
residual(31) = 1-exp(y(22))-exp(y(13));
residual(32) = (-exp(y(21)))+exp(y(20))/exp(y(22));
residual(33) = (-exp(y(19)))+exp(y(20))/exp(y(14));
residual(34) = (-exp(y(52)))+T444/(1-exp(y(24)));
residual(35) = (-exp(y(23)))+exp(y(52))^((1-params(10))/params(20));
residual(36) = (-exp(y(24)))+0.5+0.5*erf(log(exp(y(18)))/(params(9)*1.414213562373095));
residual(37) = (-exp(y(25)))+T464;
residual(38) = (-exp(y(53)))+exp(y(25))*T467^params(21);
residual(39) = (-exp(y(26)))+T476;
residual(40) = y(66)+(-exp(y(28)))+exp(y(27));
residual(41) = exp(y(26))-exp(y(33));
residual(42) = exp(y(12))-exp(y(55))-params(23)*(1-exp(y(13)));
residual(43) = (-exp(y(51)))+exp(y(12))^(-params(1));
residual(44) = (-y(57))+params(3)*y(8)-x(it_, 1)+x(it_, 5);
residual(45) = (-y(65))+params(74);
residual(46) = (-y(66))+params(75);
residual(47) = (-y(67))+params(76);
residual(48) = x(it_, 5)+(-y(68))+(1-params(24))*log(params(79))+params(24)*y(9)+x(it_, 2);
residual(49) = x(it_, 5)+(-y(69))+(1-params(25))*log(params(81))+params(25)*y(10)+x(it_, 3);
residual(50) = x(it_, 5)+(-y(70))+(1-params(26))*log(params(83))+params(26)*y(11)+x(it_, 4);
residual(51) = (1-exp(y(24)))*(1-params(5))*params(13)+(1-params(5))*exp(y(24))+params(5)-exp(y(54));
residual(52) = (-exp(y(58)))+exp(y(15))*exp(y(13))+exp(y(1))*exp(y(33))+exp(y(38))*exp(y(39));
residual(53) = (params(18)+y(67))*exp(y(40))-exp(y(56));
residual(54) = (-exp(y(59)))+exp(y(58))/exp(y(41));
residual(55) = (-exp(y(60)))+exp(y(55))/exp(y(41));
residual(56) = (-exp(y(61)))+exp(y(17))/exp(y(41));
residual(57) = (-exp(y(63)))+exp(y(15))/exp(y(41));
residual(58) = (-exp(y(64)))+exp(y(12))/exp(y(41));
residual(59) = (-exp(y(62)))+exp(y(56))/exp(y(41));
residual(60) = (-exp(y(71)))+exp(y(14))/exp(y(22));
residual(61) = T635*(params(17)*exp(y(71))+T640)+y(65)+params(23)-exp(y(72));
residual(62) = (1-params(5))*exp(y(24))+params(5)-exp(y(73));
residual(63) = 1-exp(y(74))-(1-params(13))*(1-exp(y(73)));
residual(64) = (-exp(y(75)))+exp(y(13))*exp(y(74))-exp(y(19))*params(5)*exp(y(13));
residual(65) = (-exp(y(76)))+exp(y(19))*exp(y(14))-exp(y(19))*params(5)*exp(y(13));
residual(66) = exp(y(76))-exp(y(77))-exp(y(75));
residual(67) = (-exp(y(79)))+T684;
residual(68) = exp(y(14))-exp(y(78))-exp(y(79));
if nargout >= 2,
  g1 = zeros(68, 96);

  %
  % Jacobian matrix
  %

  g1(1,12)=(-1);
  g1(1,49)=1;
  g1(2,49)=(-1);
  g1(2,50)=1;
  g1(2,89)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(24)))*exp(y(3))*exp(y(6));
  g1(3,24)=exp(y(7))*(1-params(5))*(-exp(y(24)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(24)));
  g1(3,6)=(1-params(5))*(1-exp(y(24)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(24)))*exp(y(7));
  g1(3,47)=(-exp(y(47)));
  g1(4,19)=(-((-params(17))*exp(y(19))))/(exp(y(19))*exp(y(19)));
  g1(4,81)=(1-params(5))*(1-params(13))*T53*(exp(y(82))*(-exp(y(81)))-exp(y(81))*y(66));
  g1(4,82)=(1-params(5))*(1-params(13))*T53*(1-exp(y(81)))*exp(y(82));
  g1(4,51)=((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(66))*(1-params(5))*(1-params(13))*T951;
  g1(4,90)=(1-params(5))*(1-params(13))*T53*((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(66));
  g1(4,66)=(1-params(5))*(1-params(13))*T53*(-exp(y(81)));
  g1(5,19)=(-((-(params(17)*exp(y(19))))/(exp(y(19))*exp(y(19)))));
  g1(5,31)=exp(y(31));
  g1(5,53)=(-exp(y(53)));
  g1(5,66)=(-1);
  g1(6,28)=(-exp(y(28)));
  g1(6,29)=T90;
  g1(6,69)=(1-params(6))/params(6)*exp(y(29))*exp(y(69))/((1-exp(y(69)))*(1-exp(y(69))));
  g1(7,15)=exp(y(15));
  g1(7,25)=(-(params(6)*exp(y(25))));
  g1(7,31)=(-exp(y(31)));
  g1(7,53)=(-((-exp(y(53)))*params(6)));
  g1(8,13)=T117*exp(y(13))*getPowerDeriv(exp(y(13)),1-params(10),1);
  g1(8,1)=T121*exp(y(57))*exp(y(23))^params(20)*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,23)=T121*exp(y(1))^params(10)*exp(y(57))*exp(y(23))*getPowerDeriv(exp(y(23)),params(20),1);
  g1(8,45)=(-exp(y(45)));
  g1(8,57)=T117*T121;
  g1(9,15)=(-(exp(y(47))*exp(y(15))));
  g1(9,24)=(-(((1-exp(y(24)))*y(66)*exp(y(47))*exp(y(24))-y(66)*exp(y(47))*exp(y(24))*(-exp(y(24))))/((1-exp(y(24)))*(1-exp(y(24))))));
  g1(9,26)=(-(exp(y(26))*exp(y(48))));
  g1(9,38)=(-exp(y(38)));
  g1(9,41)=exp(y(41))*exp(y(44));
  g1(9,44)=exp(y(41))*exp(y(44));
  g1(9,46)=(-(params(17)*exp(y(46))));
  g1(9,47)=(-(exp(y(47))*exp(y(15))))-y(66)*exp(y(47))*exp(y(24))/(1-exp(y(24)));
  g1(9,48)=(-(exp(y(26))*exp(y(48))));
  g1(9,66)=(-(exp(y(47))*exp(y(24))/(1-exp(y(24)))));
  g1(10,19)=params(17)*T815;
  g1(10,37)=(-exp(y(37)));
  g1(10,46)=params(17)*exp(y(46));
  g1(10,47)=params(17)*T158;
  g1(10,67)=1;
  g1(11,39)=(-(exp(y(45))*exp(y(39))))/(exp(y(39))*exp(y(39)));
  g1(11,44)=(-exp(y(44)));
  g1(11,45)=exp(y(45))/exp(y(39));
  g1(12,34)=exp(y(43))*exp(y(34));
  g1(12,41)=(-exp(y(41)));
  g1(12,43)=exp(y(43))*exp(y(34));
  g1(13,37)=(-exp(y(37)));
  g1(13,87)=T179*exp(y(87));
  g1(13,88)=T179*exp(y(88));
  g1(13,51)=(exp(y(87))+exp(y(88)))*params(2)*(1-params(13))*T956;
  g1(13,90)=T179*(exp(y(87))+exp(y(88)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,39)=(-exp(y(39)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,39)=exp(y(41))*T205*(exp(y(39))*params(14)*params(15)*(-exp(y(39)))*.5-.5*(params(14)-exp(y(39)))*exp(y(39))*params(14)*params(15))/(exp(y(39))*params(14)*params(15)*exp(y(39))*params(14)*params(15));
  g1(15,41)=exp(y(41))*T205;
  g1(16,42)=(exp(y(42))*(exp(y(42))-1)-exp(y(42))*exp(y(42)))/((exp(y(42))-1)*(exp(y(42))-1));
  g1(16,43)=(-exp(y(43)));
  g1(17,39)=exp(y(39))*params(15);
  g1(17,42)=(-exp(y(42)));
  g1(18,32)=T225;
  g1(18,39)=(-(exp(y(39))*1/exp(y(41))*exp(y(32))))/(exp(y(39))*exp(y(39)));
  g1(18,41)=exp(y(32))*(-exp(y(41)))/(exp(y(41))*exp(y(41)))/exp(y(39));
  g1(18,44)=(-exp(y(44)));
  g1(19,14)=params(17)*exp(y(14));
  g1(19,17)=exp(y(17));
  g1(19,24)=((1-exp(y(24)))*y(66)*exp(y(47))*exp(y(24))*exp(y(39))-y(66)*exp(y(47))*exp(y(24))*exp(y(39))*(-exp(y(24))))/((1-exp(y(24)))*(1-exp(y(24))));
  g1(19,32)=(-exp(y(32)));
  g1(19,39)=T245;
  g1(19,40)=(params(18)+y(67))*exp(y(40));
  g1(19,47)=T245;
  g1(19,55)=exp(y(55));
  g1(19,66)=exp(y(47))*exp(y(24))*exp(y(39))/(1-exp(y(24)));
  g1(19,67)=exp(y(40));
  g1(19,68)=exp(y(68));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,16)=(-exp(y(16)));
  g1(20,17)=exp(y(17))*T263;
  g1(20,36)=exp(y(17))*(-(params(12)/2*2*y(36)));
  g1(21,84)=T53*exp(y(84))*(1-exp(y(70)));
  g1(21,35)=(-exp(y(35)));
  g1(21,85)=T53*(1-params(19))*exp(y(85));
  g1(21,51)=(exp(y(84))*(1-exp(y(70)))+(1-params(19))*exp(y(85)))*T951;
  g1(21,90)=T53*(exp(y(84))*(1-exp(y(70)))+(1-params(19))*exp(y(85)));
  g1(21,70)=T53*exp(y(84))*(-exp(y(70)));
  g1(22,2)=exp(y(35))*(-(params(12)*y(36)*T765));
  g1(22,17)=exp(y(35))*(-(params(12)*y(36)*T286))+exp(y(85))*T53*params(12)*y(86)*(-(exp(y(17))*exp(y(80))))/(exp(y(17))*exp(y(17)))*2*T296;
  g1(22,80)=exp(y(85))*T53*params(12)*y(86)*T296*2*T296;
  g1(22,35)=T289;
  g1(22,85)=T299;
  g1(22,36)=exp(y(35))*((-(params(12)/2*2*y(36)))-params(12)*T286);
  g1(22,86)=exp(y(85))*T53*params(12)*T296^2;
  g1(22,51)=y(86)*T296^2*exp(y(85))*params(12)*T951;
  g1(22,90)=T299;
  g1(23,2)=T765;
  g1(23,17)=T286;
  g1(23,36)=(-1);
  g1(24,15)=(-exp(y(15)));
  g1(24,81)=(1-params(5))*(1-params(13))*T53*(exp(y(82))*(-exp(y(81)))-exp(y(81))*y(91));
  g1(24,25)=exp(y(25));
  g1(24,27)=(-exp(y(27)));
  g1(24,82)=(1-params(5))*(1-params(13))*T53*(1-exp(y(81)))*exp(y(82));
  g1(24,51)=((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(91))*(1-params(5))*(1-params(13))*T951;
  g1(24,90)=(1-params(5))*(1-params(13))*T53*((1-exp(y(81)))*exp(y(82))-exp(y(81))*y(91));
  g1(24,91)=(1-params(5))*(1-params(13))*T53*(-exp(y(81)));
  g1(25,15)=(1-exp(y(69)))*exp(y(15));
  g1(25,81)=exp(y(83))*(1-params(5))*(1-params(13))*T53*(-exp(y(81)));
  g1(25,29)=(-exp(y(29)));
  g1(25,83)=(1-params(5))*(1-params(13))*T53*(1-exp(y(81)))*exp(y(83));
  g1(25,30)=(-exp(y(30)));
  g1(25,51)=exp(y(83))*(1-exp(y(81)))*(1-params(5))*(1-params(13))*T951;
  g1(25,90)=(1-params(5))*(1-params(13))*T53*(1-exp(y(81)))*exp(y(83));
  g1(25,69)=exp(y(15))*(-exp(y(69)));
  g1(26,21)=T340;
  g1(26,81)=exp(y(83))*T338*(-exp(y(81)));
  g1(26,83)=T340;
  g1(26,30)=(-exp(y(30)));
  g1(26,51)=exp(y(83))*(1-exp(y(81)))*exp(y(21))*params(2)*(1-params(5))*(1-params(13))*T956;
  g1(26,90)=T340;
  g1(26,65)=1;
  g1(27,14)=(-exp(y(14)));
  g1(27,19)=(-(exp(y(19))*exp(y(47))*exp(y(40))))/(exp(y(19))*exp(y(19)));
  g1(27,39)=exp(y(46))*exp(y(39));
  g1(27,40)=T348+exp(y(46))*exp(y(40));
  g1(27,46)=exp(y(46))*(exp(y(39))+exp(y(40)));
  g1(27,47)=T348;
  g1(28,13)=exp(y(13))/exp(y(39));
  g1(28,39)=(-(exp(y(13))*exp(y(39))))/(exp(y(39))*exp(y(39)));
  g1(28,47)=(-exp(y(47)));
  g1(29,1)=exp(y(1))/exp(y(39));
  g1(29,39)=(-(exp(y(1))*exp(y(39))))/(exp(y(39))*exp(y(39)));
  g1(29,48)=(-exp(y(48)));
  g1(30,14)=exp(y(22))^params(7)*params(16)*exp(y(14))*getPowerDeriv(exp(y(14)),1-params(7),1);
  g1(30,20)=(-exp(y(20)));
  g1(30,22)=params(16)*exp(y(14))^(1-params(7))*exp(y(22))*getPowerDeriv(exp(y(22)),params(7),1);
  g1(31,13)=(-exp(y(13)));
  g1(31,22)=(-exp(y(22)));
  g1(32,20)=exp(y(20))/exp(y(22));
  g1(32,21)=(-exp(y(21)));
  g1(32,22)=(-(exp(y(20))*exp(y(22))))/(exp(y(22))*exp(y(22)));
  g1(33,14)=(-(exp(y(14))*exp(y(20))))/(exp(y(14))*exp(y(14)));
  g1(33,19)=(-exp(y(19)));
  g1(33,20)=exp(y(20))/exp(y(14));
  g1(34,18)=T442*T406*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T422^2)*1.772453850905516)/params(11)^0.5/(1-exp(y(24)));
  g1(34,24)=(-(T444*(-exp(y(24)))))/((1-exp(y(24)))*(1-exp(y(24))));
  g1(34,52)=(-exp(y(52)));
  g1(35,23)=(-exp(y(23)));
  g1(35,52)=exp(y(52))*getPowerDeriv(exp(y(52)),(1-params(10))/params(20),1);
  g1(36,18)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(18)))/(params(9)*1.414213562373095))^2));
  g1(36,24)=(-exp(y(24)));
  g1(37,13)=(-(exp(y(13))*exp(y(45))*(1-params(10))*exp(y(34))))/(exp(y(13))*exp(y(13)));
  g1(37,25)=(-exp(y(25)));
  g1(37,34)=T464;
  g1(37,45)=T464;
  g1(38,18)=exp(y(25))*T467*getPowerDeriv(T467,params(21),1);
  g1(38,23)=exp(y(25))*getPowerDeriv(T467,params(21),1)*(-(exp(y(23))*exp(y(18))))/(exp(y(23))*exp(y(23)));
  g1(38,25)=exp(y(25))*T467^params(21);
  g1(38,53)=(-exp(y(53)));
  g1(39,1)=(-(exp(y(1))*exp(y(45))*params(10)*exp(y(34))))/(exp(y(1))*exp(y(1)));
  g1(39,26)=(-exp(y(26)));
  g1(39,34)=T476;
  g1(39,45)=T476;
  g1(40,27)=exp(y(27));
  g1(40,28)=(-exp(y(28)));
  g1(40,66)=1;
  g1(41,26)=exp(y(26));
  g1(41,33)=(-exp(y(33)));
  g1(42,12)=exp(y(12));
  g1(42,13)=(-(params(23)*(-exp(y(13)))));
  g1(42,55)=(-exp(y(55)));
  g1(43,12)=exp(y(12))*getPowerDeriv(exp(y(12)),(-params(1)),1);
  g1(43,51)=(-exp(y(51)));
  g1(44,8)=params(3);
  g1(44,57)=(-1);
  g1(44,92)=(-1);
  g1(44,96)=1;
  g1(45,65)=(-1);
  g1(46,66)=(-1);
  g1(47,67)=(-1);
  g1(48,9)=params(24);
  g1(48,68)=(-1);
  g1(48,93)=1;
  g1(48,96)=1;
  g1(49,10)=params(25);
  g1(49,69)=(-1);
  g1(49,94)=1;
  g1(49,96)=1;
  g1(50,11)=params(26);
  g1(50,70)=(-1);
  g1(50,95)=1;
  g1(50,96)=1;
  g1(51,24)=(1-params(5))*exp(y(24))+(-exp(y(24)))*(1-params(5))*params(13);
  g1(51,54)=(-exp(y(54)));
  g1(52,13)=exp(y(15))*exp(y(13));
  g1(52,15)=exp(y(15))*exp(y(13));
  g1(52,1)=exp(y(1))*exp(y(33));
  g1(52,33)=exp(y(1))*exp(y(33));
  g1(52,38)=exp(y(38))*exp(y(39));
  g1(52,39)=exp(y(38))*exp(y(39));
  g1(52,58)=(-exp(y(58)));
  g1(53,40)=(params(18)+y(67))*exp(y(40));
  g1(53,56)=(-exp(y(56)));
  g1(53,67)=exp(y(40));
  g1(54,41)=(-(exp(y(41))*exp(y(58))))/(exp(y(41))*exp(y(41)));
  g1(54,58)=exp(y(58))/exp(y(41));
  g1(54,59)=(-exp(y(59)));
  g1(55,41)=(-(exp(y(41))*exp(y(55))))/(exp(y(41))*exp(y(41)));
  g1(55,55)=exp(y(55))/exp(y(41));
  g1(55,60)=(-exp(y(60)));
  g1(56,17)=exp(y(17))/exp(y(41));
  g1(56,41)=(-(exp(y(41))*exp(y(17))))/(exp(y(41))*exp(y(41)));
  g1(56,61)=(-exp(y(61)));
  g1(57,15)=exp(y(15))/exp(y(41));
  g1(57,41)=(-(exp(y(15))*exp(y(41))))/(exp(y(41))*exp(y(41)));
  g1(57,63)=(-exp(y(63)));
  g1(58,12)=exp(y(12))/exp(y(41));
  g1(58,41)=(-(exp(y(12))*exp(y(41))))/(exp(y(41))*exp(y(41)));
  g1(58,64)=(-exp(y(64)));
  g1(59,41)=(-(exp(y(41))*exp(y(56))))/(exp(y(41))*exp(y(41)));
  g1(59,56)=exp(y(56))/exp(y(41));
  g1(59,62)=(-exp(y(62)));
  g1(60,14)=exp(y(14))/exp(y(22));
  g1(60,22)=(-(exp(y(14))*exp(y(22))))/(exp(y(22))*exp(y(22)));
  g1(60,71)=(-exp(y(71)));
  g1(61,21)=T635*T640;
  g1(61,51)=T635*exp(y(21))*y(66)*(-(exp(y(51))*exp(y(90))*params(2)*(1-params(5))*(1-params(13))))/(exp(y(51))*exp(y(51)));
  g1(61,90)=T635*T640;
  g1(61,65)=1;
  g1(61,66)=T635*exp(y(21))*exp(y(90))*params(2)*(1-params(5))*(1-params(13))/exp(y(51));
  g1(61,71)=T635*params(17)*exp(y(71));
  g1(61,72)=(-exp(y(72)));
  g1(62,24)=(1-params(5))*exp(y(24));
  g1(62,73)=(-exp(y(73)));
  g1(63,73)=(-((1-params(13))*(-exp(y(73)))));
  g1(63,74)=(-exp(y(74)));
  g1(64,13)=exp(y(13))*exp(y(74))-exp(y(19))*params(5)*exp(y(13));
  g1(64,19)=(-(exp(y(19))*params(5)*exp(y(13))));
  g1(64,74)=exp(y(13))*exp(y(74));
  g1(64,75)=(-exp(y(75)));
  g1(65,13)=(-(exp(y(19))*params(5)*exp(y(13))));
  g1(65,14)=exp(y(19))*exp(y(14));
  g1(65,19)=exp(y(19))*exp(y(14))-exp(y(19))*params(5)*exp(y(13));
  g1(65,76)=(-exp(y(76)));
  g1(66,75)=(-exp(y(75)));
  g1(66,76)=exp(y(76));
  g1(66,77)=(-exp(y(77)));
  g1(67,19)=exp(y(40))*T815;
  g1(67,40)=T684;
  g1(67,46)=exp(y(46))*exp(y(40));
  g1(67,47)=T158*exp(y(40));
  g1(67,79)=(-exp(y(79)));
  g1(68,14)=exp(y(14));
  g1(68,78)=(-exp(y(78)));
  g1(68,79)=(-exp(y(79)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],68,9216);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],68,884736);
end
end
